pub enum ReviewCommand {
Status {
run_id: Option<String>,
},
Result {
run_id: Option<String>,
},
Cancel {
run_id: String,
},
}Variants
Status
Show tracked review run status, or all known runs when no id is provided.
Result
Show the latest completed/failed review run, or a specific run.
Cancel
Cancel a queued review run and remove it from the review queue.