pub struct WatcherLock {
pub identity: ProcessIdentity,
pub created_at_unix: u64,
}Expand description
On-disk single-flight lock. Records who owns the watcher slot and when it was claimed. Serialized as pretty JSON so it is human-inspectable in the state dir.
Fields
identity: ProcessIdentitycreated_at_unix: u64Trait Implementations
Sourceimpl Clone for WatcherLock
impl Clone for WatcherLock
Sourcefn clone(&self) -> WatcherLock
fn clone(&self) -> WatcherLock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WatcherLock
impl Debug for WatcherLock
Sourceimpl<'de> Deserialize<'de> for WatcherLock
impl<'de> Deserialize<'de> for WatcherLock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WatcherLock
Sourceimpl PartialEq for WatcherLock
impl PartialEq for WatcherLock
Sourcefn eq(&self, other: &WatcherLock) -> bool
fn eq(&self, other: &WatcherLock) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WatcherLock
impl Serialize for WatcherLock
impl StructuralPartialEq for WatcherLock