pub struct WatchArgs {
pub watched_agent: Option<Agent>,
pub reviewer_harness: Option<ReviewerHarness>,
pub watched_model: Option<String>,
pub reviewer_model: Option<String>,
pub allow_same_model: bool,
pub once: bool,
pub poll_secs: u64,
}Fields
watched_agent: Option<Agent>reviewer_harness: Option<ReviewerHarness>watched_model: Option<String>reviewer_model: Option<String>allow_same_model: boolonce: boolDrain the review queue exactly once and exit (deterministic; used in CI).
poll_secs: u64Poll interval in seconds when running as a daemon (ignored with –once).